pub enum FrameError {
MismatchedPlaneStride {
planes: usize,
strides: usize,
},
UnsupportedPixelFormat(PixelFormat),
UnsupportedSampleFormat(SampleFormat),
InvalidPlaneCount {
expected: usize,
actual: usize,
},
}Expand description
Error type for frame operations.
Variants
MismatchedPlaneStride
The number of planes does not match the number of strides.
UnsupportedPixelFormat(PixelFormat)
Cannot allocate a frame for an unknown pixel format.
UnsupportedSampleFormat(SampleFormat)
Cannot allocate an audio frame for an unknown sample format.
InvalidPlaneCount
The number of planes does not match the expected count for the format.