FrameError

Enum FrameError 

pub enum FrameError {
    MismatchedPlaneStride {
        planes: usize,
        strides: usize,
    },
    UnsupportedPixelFormat(PixelFormat),
    UnsupportedSampleFormat(SampleFormat),
    InvalidPlaneCount {
        expected: usize,
        actual: usize,
    },
}
Error type for frame operations.

Variants



MismatchedPlaneStride

The number of planes does not match the number of strides.

Fields

planes: usize

Number of planes provided.

strides: usize

Number of strides provided.



UnsupportedPixelFormat(PixelFormat)

Cannot allocate a frame for an unknown pixel format.



UnsupportedSampleFormat(SampleFormat)

Cannot allocate an audio frame for an unknown sample format.



InvalidPlaneCount

The number of planes does not match the expected count for the format.

Fields

expected: usize

Expected number of planes.

actual: usize

Actual number of planes provided.